#!/usr/bin/python3

import json
import re

rTatsTemplate_name = "rTatsSettingsTemplate.json"
modfile_name = "tramp.json"

tatTypes = {
         "(unassigned)": "UNA",
         "(excluded)": "EXC",
         "tally": "TAL",
         "forehead": "FH",
         "face": "F",
         "mouth": "M",
         "shoulder": "SH",
         "left arm": "LA",
         "right arm": "RA",
         "left hand": "LH",
         "right hand": "RH",
         "hands": "H",
         "breasts": "BR",
         "left breast": "LBR",
         "right breast": "RBR",
         "front middle": "FRM",
         "front lower": "FRL",
         "upper back": "UB",
         "middle back": "MB",
         "lower back": "LB",
         "pubic": "P",
         "butt": "B",
         "left cheek": "LC",
         "right cheek": "RC",
         "left leg": "LL",
         "right leg": "RL",
         "feet": "FEE",
         "misc 1 - a": "M1A",
         "misc 1 - b": "M1B",
         "misc 1 - c": "M1C",
         "misc 1 - d": "M1D",
         "misc 2 - a": "M2A",
         "misc 2 - b": "M2B",
         "misc 2 - c": "M2C",
         "misc 2 - d": "M2D",
         "misc 3 - a": "M3A",
         "misc 3 - b": "M3B",
         "misc 3 - c": "M3C",
         "misc 3 - d": "M3D"
        }

def get_key(keyid):
    for key, value in tatTypes.items():
        if keyid == value:
            return key

def get_tatto_map(tatto_name):
    for x in tatTypes:
        if str(tatTypes[x]) == tatto_name:
            new_id = get_key(tatTypes[x])
            return new_id
    return "UNA"

def open_rTatsTemplate(template_file_location):
    template = dict(json.load(open(template_file_location, 'r')))
    return template

def open_tattoModFile(mod_file_location):
    with open(mod_file_location, 'r') as f:
        modtats = json.load(f)
    return modtats

def savefile(filename, filejson):
    with open( filename, 'w' ) as savefile:
         json.dump(filejson, savefile)

def build_newtat():
    template = open_rTatsTemplate(rTatsTemplate_name)
    modtats = open_tattoModFile(modfile_name)
    for x in modtats:
        tmap = str(re.findall(r"\[(.*?)\]",(x["name"])))[2:-2]
        areamap = get_tatto_map(tmap)
        newtat = {(x['texture']):{'group': areamap}}
        template.update(newtat)
        print("Appended {} to the template file.".format(newtat))
    savefile("New" + rTatsTemplate_name, template)
build_newtat()


